==> cms-db_v0.9.tar.gz: admin/firstrun3.php <==
<?php
/*  cms-db  Copyright (C) 2007-2011 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

define('cms-db', 'backend');

include('checkuser.inc.php');
checkuser('firstrun');
include('locale.inc.php');
$locale = new LocalizingClass('firstrun');

if (isset($_POST['user']) && isset($_POST['pass'])) {
	if ($_POST['user'] != '' && $_POST['pass'] != '' && $_POST['pass'] == $_POST['repeat']) {
		include('escape.inc.php');

		$pass = sha1('root.php'.$_POST['pass']);
		$writethis = '<?php
		$user = \''.escapeForm($_POST['user']).'\';
		$pass = \''.$pass.'\';
		?>';
		file_put_contents('../data/users/root.php', $writethis);

		include('../data/settings/update.inc.php');
		$autoupdate = (isset($_POST['autoupdate'])) ? $_POST['autoupdate'] : '';
		$writethis = '<?php
		$autoupdate = \''.escapeForm($autoupdate).'\';
		$ftpserver = \''.escapeSave($ftpserver).'\';
		$ftpuser = \''.escapeSave($ftpuser).'\';
		$ftppw = \''.escapeSave($ftppw).'\';
		$ftpdir = \''.escapeSave($ftpdir).'\';
		?>';
		file_put_contents('../data/settings/update.inc.php', $writethis);

		header('Location: firstrun4.php?'.SID.csrf_protection_get());
		die();
	} else {
		$error = true;
	}
}
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php locale('title') ?></title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<link rel="stylesheet" type="text/css" href="style.css">
<link rel="stylesheet" type="text/css" href="<?php include('mobile.inc.php'); echo mobile() ? 'style-extra-mobile.css' : 'style-extra.css'; ?>" />
</head>
<body>

<h1><?php locale('title') ?></h1>
<h2><?php locale('title_settings') ?></h2>
<?php
if (isset($error)) {
	echo '<p class="error">'.locale('desc_error-userdata',true).'</p>';
}
?>
<form action="firstrun3.php?<?php echo SID; csrf_protection_get_html() ?>" method="post">
	<fieldset>
		<p>
			<?php locale('desc_user') ?>
		</p>
		<p>
			<div class="row entryrow">
				<label for="user" class="column">
					<?php locale('label_username') ?>:
				</label>
				<span class="column">
					<input type="text" name="user" id="user" value="admin" />
				</span>
			</div>

			<div class="row entryrow">
				<label for="pass" class="column">
					<?php locale('label_password') ?>:
				</label>
				<span class="column">
					<input type="password" name="pass" id="pass" value="" />
				</span>
			</div>

			<div class="row entryrow">
				<label for="repeat" class="column">
					<?php locale('desc_repeat') ?>
				</label>
				<span class="column">
					<input type="password" name="repeat" id="repeat" value="" />
				</span>
			</div>

			<br class="break" />
		</p>
	</fieldset>
	<?php if (function_exists('curl_init')) { ?>
		<fieldset>
			<p>
				<div class="row checkrow">
					<span class="column">
						<input type="checkbox" name="autoupdate" id="autoupdate" checked="checked" />
					</span>
					<label for="autoupdate" class="column">
						<strong><?php locale('label_autoupdate') ?></strong><br />
						<em><?php locale('desc_autoupdate') ?> <?php locale('desc_updatecheck') ?></em>
					</label>
				</div>
				
				<br class="break" />
			</p>
		</fieldset>
	<?php } else { ?>
		<input type="hidden" name="autoupdate" value="" />
	<?php } ?>
	<p>
		<input type="submit" name="button" value="<?php locale_escape('link_next', '"') ?>" />
	</p>
</form>

</body>
</html>

==> cms-db_v0.9.3.tar.gz: admin/firstrun3.php <==
<?php
/*  cms-db  Copyright (C) 2007-2011 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

define('cms-db', 'backend');

require_once('path.inc.php');
require_once(CDB_PATH_ADMIN.'/checkphp.inc.php');
require_once(CDB_PATH_ADMIN.'/checkuser.inc.php');
checkuser('firstrun');
require_once(CDB_PATH_ADMIN.'/locale.inc.php');
$locale = new LocalizingClass('firstrun');

if (isset($_POST['user']) && isset($_POST['pass'])) {
	if ($_POST['user'] != '' && $_POST['pass'] != '' && $_POST['pass'] == $_POST['repeat']) {
		include(CDB_PATH_ADMIN.'/escape.inc.php');

		$pass = sha1('root.php'.$_POST['pass']);
		$writethis = '<?php
		$user = \''.escapeForm($_POST['user']).'\';
		$pass = \''.$pass.'\';
		?>';
		file_put_contents(CDB_PATH_DATA.'/users/root.php', $writethis);

		include(CDB_PATH_DATA.'/settings/update.inc.php');
		$autoupdate = (isset($_POST['autoupdate'])) ? $_POST['autoupdate'] : '';
		$writethis = '<?php
		$autoupdate = \''.escapeForm($autoupdate).'\';
		$ftpserver = \''.escapeSave($ftpserver).'\';
		$ftpuser = \''.escapeSave($ftpuser).'\';
		$ftppw = \''.escapeSave($ftppw).'\';
		$ftpdir = \''.escapeSave($ftpdir).'\';
		?>';
		file_put_contents(CDB_PATH_DATA.'/settings/update.inc.php', $writethis);

		header('Location: firstrun4.php?'.SID.csrf_protection_get());
		die();
	} else {
		$error = true;
	}
}
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php locale('title') ?></title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<link rel="stylesheet" type="text/css" href="style.css">
<link rel="stylesheet" type="text/css" href="<?php include('mobile.inc.php'); echo mobile() ? 'style-extra-mobile.css' : 'style-extra.css'; ?>" />
</head>
<body>

<h1><?php locale('title') ?></h1>
<h2><?php locale('title_settings') ?></h2>
<?php
if (isset($error)) {
	echo '<p class="error">'.locale('desc_error-userdata',true).'</p>';
}
?>
<form action="firstrun3.php?<?php echo SID; csrf_protection_get_html() ?>" method="post">
	<fieldset>
		<p>
			<?php locale('desc_user') ?>
		</p>
		<p>
			<div class="row entryrow">
				<label for="user" class="column">
					<?php locale('label_username') ?>:
				</label>
				<span class="column">
					<input type="text" name="user" id="user" value="admin" />
				</span>
			</div>

			<div class="row entryrow">
				<label for="pass" class="column">
					<?php locale('label_password') ?>:
				</label>
				<span class="column">
					<input type="password" name="pass" id="pass" value="" />
				</span>
			</div>

			<div class="row entryrow">
				<label for="repeat" class="column">
					<?php locale('desc_repeat') ?>
				</label>
				<span class="column">
					<input type="password" name="repeat" id="repeat" value="" />
				</span>
			</div>

			<br class="break" />
		</p>
	</fieldset>
	<?php if (function_exists('curl_init')) { ?>
		<fieldset>
			<p>
				<div class="row checkrow">
					<span class="column">
						<input type="checkbox" name="autoupdate" id="autoupdate" checked="checked" />
					</span>
					<label for="autoupdate" class="column">
						<strong><?php locale('label_autoupdate') ?></strong><br />
						<em><?php locale('desc_autoupdate') ?> <?php locale('desc_updatecheck') ?></em>
					</label>
				</div>
				
				<br class="break" />
			</p>
		</fieldset>
	<?php } else { ?>
		<input type="hidden" name="autoupdate" value="" />
	<?php } ?>
	<p>
		<input type="submit" name="button" value="<?php locale_escape('link_next', '"') ?>" />
	</p>
</form>

</body>
</html>
